@@ -9,6 +9,12 @@ from pybuilder.core import depends
 
 from anybadge import Badge
 
+URL = {
+    'complexity': 'https://radon.readthedocs.io/en/latest/api.html#module-radon.complexity',
+    'severity': 'https://pypi.org/project/bandit/',
+    'python': 'https://www.python.org/downloads/'
+}
+
 
 @init
 def init_anybadge(project):
@@ -101,16 +107,17 @@ def get_complexity_report(lines):
         line = line.strip()
         match = re.match(regex_score, line)
         if match:
-            score = float(match.group('score'))
+            score = round(float(match.group('score')))
             if score > report['highest']['score']:
                 report['highest']['score'] = score
                 report['highest']['name'] = match.group('name')
 
     last_line = lines[-1].strip()
     regex_average = r'Average complexity: [A-Z] \((?P<average>.*)\)'
-    match = re.match(regex_average, last_line)
-    if match:
-        report['average'] = float(match.group('average'))
+    match_average = re.match(regex_average, last_line)
+    if match_average:
+        average = match_average.group('average')
+        report['average'] = round(float(average), 2)
 
     return report
 
@@ -134,7 +141,7 @@ def get_complexity_badge(complexity_report, use_average=False):
         color = 'green'
     elif score <= 10:
         value = 'Stable'
-        color = 'green'
+        color = 'olive'
     elif score <= 20:
         value = 'Slight'
         color = 'yellow'
@@ -148,7 +155,7 @@ def get_complexity_badge(complexity_report, use_average=False):
         value = 'Unstable'
         color = 'brightred'
 
-    return Badge('complexity', value=value, default_color=color, num_padding_chars=1)
+    return Badge('complexity', value=f'{value}: {score}', default_color=color, num_padding_chars=1)
 
 
 def get_severity_badge(severity_report):
@@ -219,7 +226,8 @@ def update_readme(name, badge_path, add_to_readme, logger):
         logger.warn(f'{filename} does not exist or is not accessible')
         return
     relative_path = os.path.join('docs', 'images', os.path.basename(badge_path))
-    line_to_add = f'![{name}]({relative_path})\n'
+    url = URL.get(name, 'https://pybuilder.io/')
+    line_to_add = f"[![{name}]({relative_path})]({url})\n"
     with open('README.md', 'r+') as file_handler:
         lines = file_handler.readlines()
         for line in lines:
@@ -232,49 +240,49 @@ def update_readme(name, badge_path, add_to_readme, logger):
             file_handler.writelines(lines)
 
 
+def write_badge_and_update_readme(name, badge, badge_path, logger, add_to_readme):
+    """ write badge and update readme
+    """
+    logger.info(f'writing coverage badge {badge_path}')
+    badge.write_badge(badge_path, overwrite=True)
+    update_readme(name, badge_path, add_to_readme, logger)
+
+
 def create_complexity_badge(report_path, badge_path, logger, add_to_readme, use_average):
     """ create complexity badge from radon report
     """
-    if not accessible(report_path):
-        logger.warn(f'{report_path} does not exist or is not accessible')
-        return
-    lines = read_lines(report_path)
-    report = get_complexity_report(lines)
-    badge = get_complexity_badge(report, use_average=use_average)
-    logger.info(f'writing complexity badge {badge_path}')
-    badge.write_badge(badge_path, overwrite=True)
-    update_readme('complexity', badge_path, add_to_readme, logger)
+    if accessible(report_path):
+        complexity_data = get_complexity_report(read_lines(report_path))
+        badge = get_complexity_badge(complexity_data, use_average=use_average)
+        write_badge_and_update_readme('complexity', badge, badge_path, logger, add_to_readme)
+    else:
+        logger.warn(f'{report_path} is not accessible')
 
 
 def create_severity_badge(report_path, badge_path, logger, add_to_readme):
     """ create severity badge from bandit report
     """
-    if not accessible(report_path):
-        logger.warn(f'{report_path} does not exist or is not accessible')
-        return
-    severity_report = read_data(report_path)
-    badge = get_severity_badge(severity_report)
-    logger.info(f'writing severity badge {badge_path}')
-    badge.write_badge(badge_path, overwrite=True)
-    update_readme('severity', badge_path, add_to_readme, logger)
+    if accessible(report_path):
+        severity_data = read_data(report_path)
+        badge = get_severity_badge(severity_data)
+        write_badge_and_update_readme('severity', badge, badge_path, logger, add_to_readme)
+    else:
+        logger.warn(f'{report_path} is not accessible')
 
 
 def create_coverage_badge(report_path, badge_path, logger, add_to_readme):
     """ create coverage badge from coverage report
     """
-    if not accessible(report_path):
-        logger.warn(f'{report_path} does not exist or is not accessible')
-        return
-    data = read_data(report_path)
-    coverage = get_coverage(data)
-    badge = get_coverage_badge(coverage)
-    logger.info(f'writing coverage badge {badge_path}')
-    badge.write_badge(badge_path, overwrite=True)
-    update_readme('coverage', badge_path, add_to_readme, logger)
+    if accessible(report_path):
+        coverage_data = get_coverage(read_data(report_path))
+        badge = get_coverage_badge(coverage_data)
+        write_badge_and_update_readme('coverage', badge, badge_path, logger, add_to_readme)
+    else:
+        logger.warn(f'{report_path} is not accessible')
 
 
 def create_python_badge(badge_path, logger, add_to_readme):
+    """ create python version badge
+    """
     badge = get_python_badge()
-    logger.info(f'writing python version badge {badge_path}')
-    badge.write_badge(badge_path, overwrite=True)
-    update_readme('python', badge_path, add_to_readme, logger)
+    write_badge_and_update_readme('python', badge, badge_path, logger, add_to_readme)
